# Compression CLI tool

`camt` is a `CLI` tool built in python, a tool for isolating images labeled with the labelImg tool.

## Requirements
* Python
* Pip

## How to run
Start by creating the folder that will be used as `[name]` in the command bellow

### Command 
```
$ pip install camt
$ camt compress --dest-dir [name] --src-dir [path] --format [zip, tar, gztar, bztar, or xztar]
```

# Future plans
* Add the ability to upload the zip file to a cloud provider `GCP`

# Contribution
You can contribute by opening an `Issue` or a `Pull request`.
